@@ -23,8 +23,9 @@ class Application : public Gtk::Application {
   std::unique_ptr<PresetsManager> presets_manager;
 
  protected:
-  int on_command_line(
-      const Glib::RefPtr<Gio::ApplicationCommandLine>& command_line) override;
+  int on_command_line(const Glib::RefPtr<Gio::ApplicationCommandLine>& command_line) override;
+
+  int on_handle_local_options(const Glib::RefPtr<Glib::VariantDict>& options);
 
   void on_startup() override;
   void on_activate() override;
@@ -35,8 +36,6 @@ class Application : public Gtk::Application {
   bool running_as_service = false;
 
   void create_actions();
-
-  void check_version();
 };
 
 #endif
