@@ -8,26 +8,22 @@
 #include "pulse_manager.hpp"
 #include "util.hpp"
 
-Application::Application()
-    : Gtk::Application("com.github.wwmm.pulseeffects",
-                       Gio::APPLICATION_HANDLES_COMMAND_LINE) {
+Application::Application() : Gtk::Application("com.github.wwmm.pulseeffects", Gio::APPLICATION_HANDLES_COMMAND_LINE) {
   Glib::set_application_name("PulseEffects");
   Glib::setenv("PULSE_PROP_application.id", "com.github.wwmm.pulseeffects");
   Glib::setenv("PULSE_PROP_application.icon_name", "pulseeffects");
 
-  add_main_option_entry(
-      Gio::Application::OPTION_TYPE_BOOL, "quit", 'q',
-      _("Quit PulseEffects. Useful when running in service mode."));
+  signal_handle_local_options().connect(sigc::mem_fun(*this, &Application::on_handle_local_options), false);
 
-  add_main_option_entry(Gio::Application::OPTION_TYPE_BOOL, "presets", 'p',
-                        _("Show available presets."));
+  add_main_option_entry(Gio::Application::OPTION_TYPE_BOOL, "quit", 'q',
+                        _("Quit PulseEffects. Useful when running in service mode."));
 
-  add_main_option_entry(Gio::Application::OPTION_TYPE_STRING, "load-preset",
-                        'l',
+  add_main_option_entry(Gio::Application::OPTION_TYPE_BOOL, "presets", 'p', _("Show available presets."));
+
+  add_main_option_entry(Gio::Application::OPTION_TYPE_STRING, "load-preset", 'l',
                         _("Load a preset. Example: pulseeffects -l music"));
 
-  add_main_option_entry(Gio::Application::OPTION_TYPE_BOOL, "reset", 'r',
-                        _("Reset PulseEffects."));
+  add_main_option_entry(Gio::Application::OPTION_TYPE_BOOL, "reset", 'r', _("Reset PulseEffects."));
 }
 
 Application::~Application() {
@@ -38,8 +34,7 @@ Glib::RefPtr<Application> Application::create() {
   return Glib::RefPtr<Application>(new Application());
 }
 
-int Application::on_command_line(
-    const Glib::RefPtr<Gio::ApplicationCommandLine>& command_line) {
+int Application::on_command_line(const Glib::RefPtr<Gio::ApplicationCommandLine>& command_line) {
   auto options = command_line->get_options_dict();
 
   if (options->contains("quit")) {
@@ -48,36 +43,23 @@ int Application::on_command_line(
     }
 
     quit();
-  } else if (options->contains("presets")) {
-    std::string list;
-
-    for (auto name : presets_manager->get_names(PresetType::output)) {
-      list += name + ",";
-    }
-
-    util::info(log_tag + _("Output Presets: ") + list);
-
-    list = "";
-
-    for (auto name : presets_manager->get_names(PresetType::input)) {
-      list += name + ",";
-    }
-
-    util::info(log_tag + _("Input Presets: ") + list);
   } else if (options->contains("load-preset")) {
     Glib::ustring name;
 
     if (!options->lookup_value("load-preset", name)) {
       util::debug(log_tag + "failed to load preset: " + name);
     } else {
-      presets_manager->load(PresetType::input, name);
-      presets_manager->load(PresetType::output, name);
+      if (presets_manager->preset_file_exists(PresetType::input, name)) {
+        presets_manager->load(PresetType::input, name);
+      }
+
+      if (presets_manager->preset_file_exists(PresetType::output, name)) {
+        presets_manager->load(PresetType::output, name);
+      }
     }
   } else if (options->contains("reset")) {
     settings->reset("");
 
-    settings->set_string("version", std::string(VERSION));
-
     util::info(log_tag + "All settings were reset");
   } else {
     activate();
@@ -89,6 +71,8 @@ int Application::on_command_line(
 void Application::on_startup() {
   Gtk::Application::on_startup();
 
+  util::debug(log_tag + "PE version: " + std::string(VERSION));
+
   settings = Gio::Settings::create("com.github.wwmm.pulseeffects");
 
   if (get_flags() & Gio::ApplicationFlags::APPLICATION_IS_SERVICE) {
@@ -96,7 +80,6 @@ void Application::on_startup() {
   }
 
   create_actions();
-  check_version();
 
   pm = std::make_unique<PulseManager>();
   sie = std::make_unique<SinkInputEffects>(pm.get());
@@ -113,17 +96,24 @@ void Application::on_startup() {
       sie->set_output_sink_name(name);
       soe->webrtc->set_probe_src_device(name + ".monitor");
 
-      auto info = pm->get_sink_info(name);
-      auto port = info->active_port;
-      std::string dev_name;
+      Glib::signal_timeout().connect_seconds_once(
+          [=]() {
+            auto info = pm->get_sink_info(pm->server_info.default_sink_name);
 
-      if (port != "null") {
-        dev_name = name + ":" + port;
-      } else {
-        dev_name = name;
-      }
+            if (info != nullptr) {
+              auto port = info->active_port;
+              std::string dev_name;
 
-      presets_manager->autoload(PresetType::output, dev_name);
+              if (port != "null") {
+                dev_name = name + ":" + port;
+              } else {
+                dev_name = name;
+              }
+
+              presets_manager->autoload(PresetType::output, dev_name);
+            }
+          },
+          3);
     }
   });
 
@@ -133,17 +123,24 @@ void Application::on_startup() {
     if (name != "") {
       soe->set_source_monitor_name(name);
 
-      auto info = pm->get_source_info(name);
-      auto port = info->active_port;
-      std::string dev_name;
+      Glib::signal_timeout().connect_seconds_once(
+          [=]() {
+            auto info = pm->get_source_info(pm->server_info.default_source_name);
 
-      if (port != "null") {
-        dev_name = name + ":" + port;
-      } else {
-        dev_name = name;
-      }
+            if (info != nullptr) {
+              auto port = info->active_port;
+              std::string dev_name;
 
-      presets_manager->autoload(PresetType::input, dev_name);
+              if (port != "null") {
+                dev_name = name + ":" + port;
+              } else {
+                dev_name = name;
+              }
+
+              presets_manager->autoload(PresetType::input, dev_name);
+            }
+          },
+          3);
     }
   });
 
@@ -193,10 +190,43 @@ void Application::on_activate() {
   }
 }
 
+int Application::on_handle_local_options(const Glib::RefPtr<Glib::VariantDict>& options) {
+  if (!options) {
+    std::cerr << G_STRFUNC << ": options is null." << std::endl;
+  }
+
+  // Remove some options to show that we have handled them in the local
+  // instance, so they won't be passed to the primary (remote) instance:
+  options->remove("preset");
+
+  presets_manager = std::make_unique<PresetsManager>();
+
+  if (options->contains("presets")) {
+    std::string list;
+
+    for (auto name : presets_manager->get_names(PresetType::output)) {
+      list += name + ",";
+    }
+
+    std::clog << _("Output Presets: ") + list << std::endl;
+
+    list = "";
+
+    for (auto name : presets_manager->get_names(PresetType::input)) {
+      list += name + ",";
+    }
+
+    std::clog << _("Input Presets: ") + list << std::endl;
+
+    return EXIT_SUCCESS;
+  }
+
+  return -1;
+}
+
 void Application::create_actions() {
   add_action("about", [&]() {
-    auto builder = Gtk::Builder::create_from_resource(
-        "/com/github/wwmm/pulseeffects/about.glade");
+    auto builder = Gtk::Builder::create_from_resource("/com/github/wwmm/pulseeffects/about.glade");
 
     auto dialog = (Gtk::Dialog*)builder->get_object("about_dialog").get();
 
@@ -229,28 +259,11 @@ void Application::create_actions() {
      *So we have to use the C api :-(
      */
 
-    if (!gtk_show_uri_on_window(window->gobj(), "help:pulseeffects",
-                                gtk_get_current_event_time(), nullptr)) {
+    if (!gtk_show_uri_on_window(window->gobj(), "help:pulseeffects", gtk_get_current_event_time(), nullptr)) {
       util::warning("Failed to open help!");
     }
   });
 
-  add_action("resetyes", [&] {
-    util::debug(log_tag + "Resetting configurations");
-
-    settings->reset("");
-
-    settings->set_string("version", std::string(VERSION));
-
-    withdraw_notification("reset");
-  });
-
-  add_action("resetno", [&] {
-    settings->set_string("version", std::string(VERSION));
-
-    withdraw_notification("reset");
-  });
-
   add_action("quit", [&] {
     auto window = get_active_window();
 
@@ -260,20 +273,3 @@ void Application::create_actions() {
   set_accel_for_action("app.help", "F1");
   set_accel_for_action("app.quit", "<Ctrl>Q");
 }
-
-void Application::check_version() {
-  util::debug(log_tag + "PE version: " + std::string(VERSION));
-
-  if (settings->get_string("version") != std::string(VERSION)) {
-    auto note = Gio::Notification::create(_("PulseEffects was updated"));
-
-    note->set_body(
-        _("It is recommended to reset its configuration after an "
-          "update. Do you want to do this?"));
-
-    note->add_button(_("Yes"), "app.resetyes");
-    note->add_button(_("No"), "app.resetno");
-
-    send_notification("reset", note);
-  }
-}
