@@ -12,13 +12,10 @@
 ApplicationUi::ApplicationUi(BaseObjectType* cobject,
                              const Glib::RefPtr<Gtk::Builder>& builder,
                              Application* application)
-    : Gtk::ApplicationWindow(cobject),
-      app(application),
-      settings(app->settings) {
+    : Gtk::ApplicationWindow(cobject), app(application), settings(app->settings) {
   apply_css_style("custom.css");
 
-  Gtk::IconTheme::get_default()->add_resource_path(
-      "/com/github/wwmm/pulseeffects/icons");
+  Gtk::IconTheme::get_default()->add_resource_path("/com/github/wwmm/pulseeffects/icons");
 
   // loading glade widgets
 
@@ -46,14 +43,12 @@ ApplicationUi::ApplicationUi(BaseObjectType* cobject,
   BlacklistSettingsUi::add_to_stack(stack_menu_settings);
   pulse_info_ui = PulseInfoUi::add_to_stack(stack, app->pm.get());
 
-  stack->connect_property_changed(
-      "visible-child",
-      sigc::mem_fun(*this, &ApplicationUi::on_stack_visible_child_changed));
+  stack->connect_property_changed("visible-child",
+                                  sigc::mem_fun(*this, &ApplicationUi::on_stack_visible_child_changed));
 
   // calibration
 
-  calibration_button->signal_clicked().connect(
-      sigc::mem_fun(*this, &ApplicationUi::on_calibration_button_clicked));
+  calibration_button->signal_clicked().connect(sigc::mem_fun(*this, &ApplicationUi::on_calibration_button_clicked));
 
   // signals
 
@@ -69,27 +64,24 @@ ApplicationUi::ApplicationUi(BaseObjectType* cobject,
     }
   }));
 
-  help_button->signal_clicked().connect(
-      [=]() { app->activate_action("help"); });
+  help_button->signal_clicked().connect([=]() { app->activate_action("help"); });
 
-  presets_menu_button->signal_clicked().connect(sigc::mem_fun(
-      *presets_menu_ui, &PresetsMenuUi::on_presets_menu_button_clicked));
+  presets_menu_button->signal_clicked().connect(
+      sigc::mem_fun(*presets_menu_ui, &PresetsMenuUi::on_presets_menu_button_clicked));
 
   presets_menu_label->set_text(settings->get_string("last-used-preset"));
 
-  connections.push_back(
-      settings->signal_changed("last-used-preset").connect([=](auto key) {
-        presets_menu_label->set_text(settings->get_string("last-used-preset"));
-      }));
+  connections.push_back(settings->signal_changed("last-used-preset").connect([=](auto key) {
+    presets_menu_label->set_text(settings->get_string("last-used-preset"));
+  }));
 
   // sink inputs widgets
 
-  connections.push_back(app->pm->sink_input_added.connect(
-      sigc::mem_fun(*sie_ui, &SinkInputEffectsUi::on_app_added)));
-  connections.push_back(app->pm->sink_input_changed.connect(
-      sigc::mem_fun(*sie_ui, &SinkInputEffectsUi::on_app_changed)));
-  connections.push_back(app->pm->sink_input_removed.connect(
-      sigc::mem_fun(*sie_ui, &SinkInputEffectsUi::on_app_removed)));
+  connections.push_back(app->pm->sink_input_added.connect(sigc::mem_fun(*sie_ui, &SinkInputEffectsUi::on_app_added)));
+  connections.push_back(
+      app->pm->sink_input_changed.connect(sigc::mem_fun(*sie_ui, &SinkInputEffectsUi::on_app_changed)));
+  connections.push_back(
+      app->pm->sink_input_removed.connect(sigc::mem_fun(*sie_ui, &SinkInputEffectsUi::on_app_removed)));
 
   connections.push_back(app->sie->new_latency.connect([=](int latency) {
     sie_latency = latency;
@@ -105,12 +97,12 @@ ApplicationUi::ApplicationUi(BaseObjectType* cobject,
 
   // source outputs widgets
 
-  connections.push_back(app->pm->source_output_added.connect(
-      sigc::mem_fun(*soe_ui, &SourceOutputEffectsUi::on_app_added)));
-  connections.push_back(app->pm->source_output_changed.connect(
-      sigc::mem_fun(*soe_ui, &SourceOutputEffectsUi::on_app_changed)));
-  connections.push_back(app->pm->source_output_removed.connect(
-      sigc::mem_fun(*soe_ui, &SourceOutputEffectsUi::on_app_removed)));
+  connections.push_back(
+      app->pm->source_output_added.connect(sigc::mem_fun(*soe_ui, &SourceOutputEffectsUi::on_app_added)));
+  connections.push_back(
+      app->pm->source_output_changed.connect(sigc::mem_fun(*soe_ui, &SourceOutputEffectsUi::on_app_changed)));
+  connections.push_back(
+      app->pm->source_output_removed.connect(sigc::mem_fun(*soe_ui, &SourceOutputEffectsUi::on_app_removed)));
 
   connections.push_back(app->soe->new_latency.connect([=](int latency) {
     soe_latency = latency;
@@ -132,8 +124,7 @@ ApplicationUi::ApplicationUi(BaseObjectType* cobject,
 
   auto flag = Gio::SettingsBindFlags::SETTINGS_BIND_DEFAULT;
 
-  settings->bind("use-dark-theme", Gtk::Settings::get_default().get(),
-                 "gtk_application_prefer_dark_theme", flag);
+  settings->bind("use-dark-theme", Gtk::Settings::get_default().get(), "gtk_application_prefer_dark_theme", flag);
 
   // restore window size
 
@@ -154,8 +145,7 @@ ApplicationUi::~ApplicationUi() {
 }
 
 ApplicationUi* ApplicationUi::create(Application* app_this) {
-  auto builder = Gtk::Builder::create_from_resource(
-      "/com/github/wwmm/pulseeffects/ui/application.glade");
+  auto builder = Gtk::Builder::create_from_resource("/com/github/wwmm/pulseeffects/ui/application.glade");
 
   ApplicationUi* window = nullptr;
 
@@ -167,8 +157,7 @@ ApplicationUi* ApplicationUi::create(Application* app_this) {
 void ApplicationUi::apply_css_style(std::string css_file_name) {
   auto provider = Gtk::CssProvider::create();
 
-  provider->load_from_resource("/com/github/wwmm/pulseeffects/ui/" +
-                               css_file_name);
+  provider->load_from_resource("/com/github/wwmm/pulseeffects/ui/" + css_file_name);
 
   auto screen = Gdk::Screen::get_default();
   auto priority = GTK_STYLE_PROVIDER_PRIORITY_APPLICATION;
@@ -185,45 +174,36 @@ void ApplicationUi::update_headerbar_subtitle(const int& index) {
   if (index == 0) {  // sie
     subtitle_grid->show();
 
-    headerbar_icon1->set_from_icon_name("emblem-music-symbolic",
-                                        Gtk::ICON_SIZE_MENU);
+    headerbar_icon1->set_from_icon_name("emblem-music-symbolic", Gtk::ICON_SIZE_MENU);
 
-    headerbar_icon2->set_from_icon_name("audio-speakers-symbolic",
-                                        Gtk::ICON_SIZE_MENU);
+    headerbar_icon2->set_from_icon_name("audio-speakers-symbolic", Gtk::ICON_SIZE_MENU);
 
-    null_sink_rate << std::fixed << app->pm->apps_sink_info->rate / 1000.0f
-                   << "kHz";
+    null_sink_rate << std::fixed << app->pm->apps_sink_info->rate / 1000.0f << "kHz";
 
     auto sink = app->pm->get_sink_info(app->pm->server_info.default_sink_name);
 
     current_dev_rate << std::fixed << sink->rate / 1000.0f << "kHz";
 
-    headerbar_info->set_text(
-        " ⟶ " + app->pm->apps_sink_info->format + "," + null_sink_rate.str() +
-        " ⟶ F32LE," + null_sink_rate.str() + " ⟶ " + sink->format + "," +
-        current_dev_rate.str() + " ⟶ " + std::to_string(sie_latency) + "ms ⟶ ");
+    headerbar_info->set_text(" ⟶ " + app->pm->apps_sink_info->format + "," + null_sink_rate.str() + " ⟶ F32LE," +
+                             null_sink_rate.str() + " ⟶ " + sink->format + "," + current_dev_rate.str() + " ⟶ " +
+                             std::to_string(sie_latency) + "ms ⟶ ");
 
   } else if (index == 1) {  // soe
     subtitle_grid->show();
 
-    headerbar_icon1->set_from_icon_name("audio-input-microphone-symbolic",
-                                        Gtk::ICON_SIZE_MENU);
+    headerbar_icon1->set_from_icon_name("audio-input-microphone-symbolic", Gtk::ICON_SIZE_MENU);
 
-    headerbar_icon2->set_from_icon_name("emblem-music-symbolic",
-                                        Gtk::ICON_SIZE_MENU);
+    headerbar_icon2->set_from_icon_name("emblem-music-symbolic", Gtk::ICON_SIZE_MENU);
 
-    null_sink_rate << std::fixed << app->pm->mic_sink_info->rate / 1000.0f
-                   << "kHz";
+    null_sink_rate << std::fixed << app->pm->mic_sink_info->rate / 1000.0f << "kHz";
 
-    auto source =
-        app->pm->get_source_info(app->pm->server_info.default_source_name);
+    auto source = app->pm->get_source_info(app->pm->server_info.default_source_name);
 
     current_dev_rate << std::fixed << source->rate / 1000.0f << "kHz";
 
-    headerbar_info->set_text(
-        " ⟶ " + source->format + "," + current_dev_rate.str() + " ⟶ F32LE," +
-        null_sink_rate.str() + " ⟶ " + app->pm->mic_sink_info->format + "," +
-        null_sink_rate.str() + " ⟶ " + std::to_string(soe_latency) + "ms ⟶ ");
+    headerbar_info->set_text(" ⟶ " + source->format + "," + current_dev_rate.str() + " ⟶ F32LE," +
+                             null_sink_rate.str() + " ⟶ " + app->pm->mic_sink_info->format + "," +
+                             null_sink_rate.str() + " ⟶ " + std::to_string(soe_latency) + "ms ⟶ ");
   } else if (index == 2) {  // pulse info
     subtitle_grid->hide();
   }
@@ -244,8 +224,7 @@ void ApplicationUi::on_stack_visible_child_changed() {
 void ApplicationUi::on_calibration_button_clicked() {
   auto calibration_ui = CalibrationUi::create();
 
-  auto c = app->pm->new_default_source.connect(
-      [=](auto name) { calibration_ui->set_source_monitor_name(name); });
+  auto c = app->pm->new_default_source.connect([=](auto name) { calibration_ui->set_source_monitor_name(name); });
 
   calibration_ui->signal_hide().connect([calibration_ui, c]() {
     c->disconnect();
