@@ -1,19 +1,16 @@
 #include "autogain_preset.hpp"
 
 AutoGainPreset::AutoGainPreset()
-    : output_settings(Gio::Settings::create(
-          "com.github.wwmm.pulseeffects.sinkinputs.autogain")) {}
+    : output_settings(Gio::Settings::create("com.github.wwmm.pulseeffects.sinkinputs.autogain")) {}
 
 void AutoGainPreset::save(boost::property_tree::ptree& root,
                           const std::string& section,
                           const Glib::RefPtr<Gio::Settings>& settings) {
   root.put(section + ".autogain.state", settings->get_boolean("state"));
 
-  root.put(section + ".autogain.input-gain",
-           settings->get_double("input-gain"));
+  root.put(section + ".autogain.input-gain", settings->get_double("input-gain"));
 
-  root.put(section + ".autogain.output-gain",
-           settings->get_double("output-gain"));
+  root.put(section + ".autogain.output-gain", settings->get_double("output-gain"));
 
   root.put(section + ".autogain.target", settings->get_double("target"));
 
@@ -29,11 +26,9 @@ void AutoGainPreset::load(boost::property_tree::ptree& root,
                           const Glib::RefPtr<Gio::Settings>& settings) {
   update_key<bool>(root, settings, "state", section + ".autogain.state");
 
-  update_key<double>(root, settings, "input-gain",
-                     section + ".autogain.input-gain");
+  update_key<double>(root, settings, "input-gain", section + ".autogain.input-gain");
 
-  update_key<double>(root, settings, "output-gain",
-                     section + ".autogain.output-gain");
+  update_key<double>(root, settings, "output-gain", section + ".autogain.output-gain");
 
   update_key<double>(root, settings, "target", section + ".autogain.target");
 
@@ -44,15 +39,13 @@ void AutoGainPreset::load(boost::property_tree::ptree& root,
   update_key<int>(root, settings, "weight-i", section + ".autogain.weight-i");
 }
 
-void AutoGainPreset::write(PresetType preset_type,
-                           boost::property_tree::ptree& root) {
+void AutoGainPreset::write(PresetType preset_type, boost::property_tree::ptree& root) {
   if (preset_type == PresetType::output) {
     save(root, "output", output_settings);
   }
 }
 
-void AutoGainPreset::read(PresetType preset_type,
-                          boost::property_tree::ptree& root) {
+void AutoGainPreset::read(PresetType preset_type, boost::property_tree::ptree& root) {
   if (preset_type == PresetType::output) {
     load(root, "output", output_settings);
   }
